@@ -78,7 +78,7 @@ def parse_gitlab() -> RequiredModelDetails:
     if REPO:
         REPO = "/".join(REPO.split("/")[1:])
 
-    BRANCH = os.getenv("CI_COMMIT_BRANCH")
+    BRANCH = os.getenv("CI_COMMIT_REF_NAME")
 
     COMMIT = os.getenv("CI_COMMIT_SHA")
 
@@ -184,10 +184,6 @@ def commit_configs(
     # false, which is why this oneliner works.
     api_url = api_url or TRANSFORM_API_URL
 
-    # Clean up branch name because people like to put slashes in their branch names
-    if "/" in branch:
-        branch = branch.replace("/", "__")  # dunder, for readability... to the extent it matters
-
     # get the config files
     yaml_files = read_config_files(config_dir)
     hash_to_filename = hash_config_files(yaml_files)
@@ -384,6 +380,13 @@ if __name__ == "__main__":
     BRANCH = f"{model_details.BRANCH}"
     COMMIT = f"{model_details.COMMIT}"
 
+    # Clean up branch name because people like to put slashes in their branch names
+    if "/" in BRANCH:
+        BRANCH = BRANCH.replace("/", "__")  # dunder, for readability... to the extent it matters
+
+    if "/" in REPO:
+        REPO = REPO.replace("/", "__")
+
     lint_results = ConfigLinter().lint_dir(TRANSFORM_CONFIG_DIR or LOCAL_DIR_DEFAULT)
     if lint_results.has_blocking_issues:
         _print_issues(lint_results)
